Enum EquipmentSlot
pub enum EquipmentSlot {
MainHand,
OffHand,
Feet,
Legs,
Chest,
Head,
Body,
Saddle,
}Expand description
Equipment slots for entities.
Based on Minecraft’s EquipmentSlot enum.
Variants
MainHand
The main hand slot.
OffHand
The off hand slot.
Feet
The feet armor slot (boots).
Legs
The legs armor slot (leggings).
Chest
The chest armor slot (chestplate).
Head
The head armor slot (helmet).
Body
The body armor slot (for animals like horses).
Saddle
The saddle slot (for rideable animals).
Implementations
impl EquipmentSlot
impl EquipmentSlot
pub const ALL: [EquipmentSlot; 8]
pub const ALL: [EquipmentSlot; 8]
All equipment slots in order.
pub const ARMOR_SLOTS: [EquipmentSlot; 4]
pub const ARMOR_SLOTS: [EquipmentSlot; 4]
Humanoid armor slots (head, chest, legs, feet).
pub const fn slot_type(self) -> EquipmentSlotType
pub const fn slot_type(self) -> EquipmentSlotType
Returns the slot type for this equipment slot.
pub const fn can_increase_experience(self) -> bool
pub const fn can_increase_experience(self) -> bool
Returns vanilla EquipmentSlot.canIncreaseExperience.
pub const fn by_id(id: i32) -> EquipmentSlot
pub const fn by_id(id: i32) -> EquipmentSlot
Returns the equipment slot with the given vanilla protocol ID.
pub const fn by_name(name: &str) -> Option<EquipmentSlot>
pub const fn by_name(name: &str) -> Option<EquipmentSlot>
Returns the equipment slot with the given name, or None if not found.